@@ -148,12 +148,18 @@ def plot_signal_analysis(py_filename, output_folder, start_date, end_date, para_
 
 
 def plot(mode, all_para_combination={},  subchart_settings={}, number_of_curves=20, risk_free_rate='geometric_mean'):
+
+    if subchart_settings == {}: # subchart default setting
+        subchart_settings = {
+            'histogram_period': [1, 3, 5, 10, 20],
+            'subchart_1': ['volume', 'line']
+        }
+
     if mode == 'equity_curves':
         result_df = pd.read_csv('backtest_result.csv', index_col=0)
         app = equity_curves.Plot(all_para_combination, result_df, subchart_settings, number_of_curves)
 
     if mode == 'aggregate':
-
         app = aggregate.Aggregate(risk_free_rate)
 
 
